==> server-api-impl-10.2.0-702.113-sources.jar: com/xebialabs/deployit/core/rest/json/DeploymentInfoJsonReaderWriter.java <==
package com.xebialabs.deployit.core.rest.json;

import com.google.common.annotations.VisibleForTesting;
import com.xebialabs.deployit.engine.api.dto.DeploymentInfo;
import com.xebialabs.xltype.serialization.json.DeploymentInfoJsonConverter;
import org.apache.commons.io.IOUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.ws.rs.Consumes;
import javax.ws.rs.Produces;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.ext.MessageBodyReader;
import javax.ws.rs.ext.MessageBodyWriter;
import javax.ws.rs.ext.Provider;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.lang.annotation.Annotation;
import java.lang.reflect.Type;
import java.nio.charset.StandardCharsets;

@Component
@Provider
@Consumes({MediaType.APPLICATION_JSON})
@Produces({MediaType.APPLICATION_JSON})
public class DeploymentInfoJsonReaderWriter implements MessageBodyWriter<DeploymentInfo>, MessageBodyReader<DeploymentInfo> {

    @Autowired
    public DeploymentInfoJsonReaderWriter() {
    }

    @Override
    public boolean isWriteable(Class<?> type, Type genericType, Annotation[] annotations, MediaType mediaType) {
        return isReadable(type, genericType, annotations, mediaType);
    }

    @Override
    public boolean isReadable(Class<?> type, Type genericType, Annotation[] annotations, MediaType mediaType) {
        return DeploymentInfo.class.isAssignableFrom(type);
    }

    @Override
    public long getSize(final DeploymentInfo info, final Class<?> type, final Type genericType, final Annotation[] annotations, final MediaType mediaType) {
        return -1L;
    }

    @Override
    public void writeTo(final DeploymentInfo info, final Class<?> type, final Type genericType, final Annotation[] annotations, final MediaType mediaType, final MultivaluedMap<String, Object> httpHeaders, final OutputStream entityStream) throws IOException, WebApplicationException {
        entityStream.write(toJson(info).getBytes());
    }

    @VisibleForTesting
    String toJson(final DeploymentInfo info) {
        return getConverter().toJson(info);
    }

    private DeploymentInfoJsonConverter getConverter() {
        return new DeploymentInfoJsonConverter();
    }


    @Override
    public DeploymentInfo readFrom(Class<DeploymentInfo> type, Type genericType, Annotation[] annotations, MediaType mediaType, MultivaluedMap<String, String> httpHeaders, InputStream entityStream) throws IOException, WebApplicationException {
        String json = IOUtils.toString(entityStream, StandardCharsets.UTF_8);
        return getConverter().toDeploymentInfo(json);
    }
}

==> server-api-impl-25.1.0-1213.113-sources.jar: com/xebialabs/deployit/core/rest/json/DeploymentInfoJsonReaderWriter.java <==
package com.xebialabs.deployit.core.rest.json;

import com.google.common.annotations.VisibleForTesting;
import com.xebialabs.deployit.engine.api.dto.DeploymentInfo;
import com.xebialabs.xltype.serialization.json.DeploymentInfoJsonConverter;
import org.apache.commons.io.IOUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import jakarta.ws.rs.Consumes;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.WebApplicationException;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.MultivaluedMap;
import jakarta.ws.rs.ext.MessageBodyReader;
import jakarta.ws.rs.ext.MessageBodyWriter;
import jakarta.ws.rs.ext.Provider;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.lang.annotation.Annotation;
import java.lang.reflect.Type;
import java.nio.charset.StandardCharsets;

@Component
@Provider
@Consumes({MediaType.APPLICATION_JSON})
@Produces({MediaType.APPLICATION_JSON})
public class DeploymentInfoJsonReaderWriter implements MessageBodyWriter<DeploymentInfo>, MessageBodyReader<DeploymentInfo> {

    @Autowired
    public DeploymentInfoJsonReaderWriter() {
    }

    @Override
    public boolean isWriteable(Class<?> type, Type genericType, Annotation[] annotations, MediaType mediaType) {
        return isReadable(type, genericType, annotations, mediaType);
    }

    @Override
    public boolean isReadable(Class<?> type, Type genericType, Annotation[] annotations, MediaType mediaType) {
        return DeploymentInfo.class.isAssignableFrom(type);
    }

    @Override
    public long getSize(final DeploymentInfo info, final Class<?> type, final Type genericType, final Annotation[] annotations, final MediaType mediaType) {
        return -1L;
    }

    @Override
    public void writeTo(final DeploymentInfo info, final Class<?> type, final Type genericType, final Annotation[] annotations, final MediaType mediaType, final MultivaluedMap<String, Object> httpHeaders, final OutputStream entityStream) throws IOException, WebApplicationException {
        entityStream.write(toJson(info).getBytes());
    }

    @VisibleForTesting
    String toJson(final DeploymentInfo info) {
        return getConverter().toJson(info);
    }

    private DeploymentInfoJsonConverter getConverter() {
        return new DeploymentInfoJsonConverter();
    }


    @Override
    public DeploymentInfo readFrom(Class<DeploymentInfo> type, Type genericType, Annotation[] annotations, MediaType mediaType, MultivaluedMap<String, String> httpHeaders, InputStream entityStream) throws IOException, WebApplicationException {
        String json = IOUtils.toString(entityStream, StandardCharsets.UTF_8);
        return getConverter().toDeploymentInfo(json);
    }
}
